summaryrefslogtreecommitdiff
path: root/gst/aiff
diff options
context:
space:
mode:
authorMatthieu Bouron <matthieu.bouron@collabora.com>2013-08-15 13:58:48 +0100
committerTim-Philipp Müller <tim@centricular.net>2013-08-17 00:25:49 +0100
commitddcfe3ddf38660280cbd5d73a32bba5128a70685 (patch)
treed45babfdc1914ec523ef99f109f02c25ef0b3f23 /gst/aiff
parentd69b6e53e463bc96b7457c3a3f99f1d07c891610 (diff)
downloadgstreamer-plugins-bad-ddcfe3ddf38660280cbd5d73a32bba5128a70685.tar.gz
aiffparse: s/newsegment/segment/
https://bugzilla.gnome.org/show_bug.cgi?id=705993
Diffstat (limited to 'gst/aiff')
-rw-r--r--gst/aiff/aiffparse.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gst/aiff/aiffparse.c b/gst/aiff/aiffparse.c
index 6b6540d74..183e0b9e1 100644
--- a/gst/aiff/aiffparse.c
+++ b/gst/aiff/aiffparse.c
@@ -442,11 +442,11 @@ gst_aiff_parse_perform_seek (GstAiffParse * aiff, GstEvent * event)
aiff->segment.format, aiff->segment.position));
}
- /* now create the newsegment */
- GST_DEBUG_OBJECT (aiff, "Creating newsegment from %" G_GINT64_FORMAT
+ /* now create the segment */
+ GST_DEBUG_OBJECT (aiff, "Creating segment from %" G_GINT64_FORMAT
" to %" G_GINT64_FORMAT, aiff->segment.position, stop);
/* store the newsegment event so it can be sent from the streaming thread. */
if (aiff->start_segment)
gst_event_unref (aiff->start_segment);
aiff->start_segment = gst_event_new_segment (&aiff->segment);
@@ -1019,7 +1019,7 @@ gst_aiff_parse_stream_headers (GstAiffParse * aiff)
/* now we have all the info to perform a pending seek if any, if no
* event, this will still do the right thing and it will also send
* the right newsegment event downstream. */
gst_aiff_parse_perform_seek (aiff, aiff->seek_event);
/* remove pending event */
event_p = &aiff->seek_event;
@@ -442,11 +442,11 @@ gst_aiff_parse_perform_seek (GstAiffParse * aiff, GstEvent * event)
" to %" G_GINT64_FORMAT, aiff->segment.position, stop);
- /* store the newsegment event so it can be sent from the streaming thread. */
+ /* store the segment event so it can be sent from the streaming thread. */
if (aiff->start_segment)
gst_event_unref (aiff->start_segment);
@@ -1019,7 +1019,7 @@ gst_aiff_parse_stream_headers (GstAiffParse * aiff)
/* now we have all the info to perform a pending seek if any, if no
* event, this will still do the right thing and it will also send
- * the right newsegment event downstream. */
+ * the right segment event downstream. */
gst_aiff_parse_perform_seek (aiff, aiff->seek_event);
/* remove pending event */